pub struct DeviceRegisterReadResponse {
pub data: Vec<u8>,
}Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceRegisterReadResponse
impl Clone for DeviceRegisterReadResponse
Sourcefn clone(&self) -> DeviceRegisterReadResponse
fn clone(&self) -> DeviceRegisterReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRegisterReadResponse
impl Debug for DeviceRegisterReadResponse
Sourceimpl<'a, ___E> Encode<DeviceRegisterReadResponse<'static>, ___E> for &'a DeviceRegisterReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceRegisterReadResponse<'static>, ___E> for &'a DeviceRegisterReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterReadResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterReadResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRegisterReadResponse<'static>, ___E> for DeviceRegisterReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceRegisterReadResponse<'static>, ___E> for DeviceRegisterReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterReadResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterReadResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceRegisterReadResponse<'static>>, ___E> for &'a DeviceRegisterReadResponsewhere
___E: Encoder + ?Sized,
&'a DeviceRegisterReadResponse: Encode<DeviceRegisterReadResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceRegisterReadResponse<'static>>, ___E> for &'a DeviceRegisterReadResponsewhere
___E: Encoder + ?Sized,
&'a DeviceRegisterReadResponse: Encode<DeviceRegisterReadResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceRegisterReadResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceRegisterReadResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceRegisterReadResponse<'static>>, ___E> for DeviceRegisterReadResponsewhere
___E: Encoder + ?Sized,
DeviceRegisterReadResponse: Encode<DeviceRegisterReadResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceRegisterReadResponse<'static>>, ___E> for DeviceRegisterReadResponsewhere
___E: Encoder + ?Sized,
DeviceRegisterReadResponse: Encode<DeviceRegisterReadResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceRegisterReadResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceRegisterReadResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceRegisterReadResponse<'de>> for DeviceRegisterReadResponse
impl<'de> FromWire<DeviceRegisterReadResponse<'de>> for DeviceRegisterReadResponse
Sourcefn from_wire(wire: DeviceRegisterReadResponse<'de>) -> Self
fn from_wire(wire: DeviceRegisterReadResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceRegisterReadResponse<'de>> for DeviceRegisterReadResponse
impl<'de> FromWireRef<DeviceRegisterReadResponse<'de>> for DeviceRegisterReadResponse
Sourcefn from_wire_ref(wire: &DeviceRegisterReadResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceRegisterReadResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceRegisterReadResponse
impl Hash for DeviceRegisterReadResponse
Sourceimpl Ord for DeviceRegisterReadResponse
impl Ord for DeviceRegisterReadResponse
Sourcefn cmp(&self, other: &DeviceRegisterReadResponse) -> Ordering
fn cmp(&self, other: &DeviceRegisterReadResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceRegisterReadResponse
impl PartialEq for DeviceRegisterReadResponse
Sourcefn eq(&self, other: &DeviceRegisterReadResponse) -> bool
fn eq(&self, other: &DeviceRegisterReadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceRegisterReadResponse
impl PartialOrd for DeviceRegisterReadResponse
impl Eq for DeviceRegisterReadResponse
impl StructuralPartialEq for DeviceRegisterReadResponse